@@ -16,6 +16,8 @@ import discord
 import datetime
 import aiosqlite
 
+from discord.ext import commands
+
 RED = 0xD40C00
 BLUE = 0x0000FF
 GREEN = 0x32C12C
@@ -32,6 +34,23 @@ print("""
 ===========================================================================================
 """)
 
+class misc:
+
+    async def reload(ctx, bot, cogs, **kwargs):
+        if not isinstance(cogs, list):
+            raise Exception("cogs must be a list.")
+        total = len(cogs)
+        reloaded = 0
+        for cog in cogs:
+            try:
+                bot.reload_extension(cog)
+                reloaded += 1
+            except:
+                continue
+        embed = discord.Embed(color = GREEN, description = f"**Successfully reloaded {reloaded}/{total} extensions.**")
+        await ctx.send(embed=embed, delete_after=7)
+        
+
 class admin:
 
     async def mute(ctx, member, *args, role_add=1, role_remove=1, reason=None, **kwargs):
